/*****************************************************  Device Defaults  ******************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following defaults are assigned to structures defined in the device functions header.

	Rev History: 1-10-2014:		Inital release.

	Copyright 2014, Red Rapids, Inc.

*****************************************************  Device Defaults  ******************************************************/

#ifndef _DEVICE_DEFAULTS_H_
#define _DEVICE_DEFAULTS_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Initialize a default structure for the Model 376 device initialization.
s_M376Devices M376Default = {
	{	// RX1TO2_ADC - REFER TO THE ADC12D1600 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes all addresses in sequence.
		{
		// {4-bit Address, 16-bit Data}
		{0x0,0x6010},	// Configuration Register 1  (DDR 90 Phase, High Voltage, Two's Complement)
		{0x2,0x0000},	// I-channel Offset Adjust  (Device Default)
		{0x3,0x4000},	// I-channel Full-Scale Range Adjust  (Device Default)
		{0x4,0xDF4B},	// Calibration Adjust  (Device Default)
		{0x5,0x0000},	// Calibration Values  (Read Only - Data Not Used)
		{0x7,0x8140},	// DES Timing Adjust  (Device Default)
		{0xA,0x0000},	// Q-channel Offset Adjust  (Device Default)
		{0xB,0x4000},	// Q-channel Full-Scale Range Adjust  (Device Default)
		{0xC,0x0004},	// Aperture Delay Coarse Adjust  (Device Default)
		{0xD,0x0000},	// Aperture Delay Fine Adjust  (Device Default)
		{0xE,0x0003}	// AutoSync  (Device Default)
		}
	},
	{	// RX1_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX2_TRIM_DAC - REFER TO THE LTC1661 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
		// The hardware initialization function writes addresses 0x1, 0x2 and 0x8 in sequence.
		// Note: Trim DAC is only present on DC coupled units.
		{
		// {4-bit Address, 10-bit Data}
		{0x1,0x000},	// Load DAC A Input Register  (Device Default)
		{0x2,0x000},	// Load DAC B Input Register  (Device Default)
		{0x8,0x000},	// Load (Update) Both DAC Output Registers - Wake Up  (Contol Only - Data Not Used)
		{0x9,0x000},	// Load DAC A Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xA,0x000},	// Load DAC B Input Register Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		{0xD,0x000},	// Wake Up  (Contol Only - Data Not Used)
		{0xE,0x000},	// Sleep  (Contol Only - Data Not Used)
		{0xF,0x000}		// Load Both DAC Input Registers (Same Value) Then Load (Update) Both DAC Output Registers - Wake Up  (Device Default)
		}
	},
	{	// RX1TO2_AMP_ENBL - REFER TO THE ADL5566 DATASHEET FOR A DETAILED DESCRIPTION OF THE ENABLE BITS.
		// The hardware initialization function writes both bits.
		// Note: Amplifier is only present on DC coupled units.
		{
		// {Command/Status Port Number, Enable}
		{4,1},	// RX1 amplifier enable (1) or disable (0).  (Enable)
		{3,1},	// RX2 amplifier enable (1) or disable (0).  (Enable)
		}
	}
};

// Initialize a default structure for the Model 377 device initialization.
s_M377Devices M377Default = {
	{  // AD9512 - REFER TO THE AD9512 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x0000,0x10},	// Serial Control Port Configuration
		{0x0034,0x01},	// Delay Bypass 4  (Device Default)
		{0x0035,0x00},	// Delay Full-Scale 4  (Device Default)
		{0x0036,0x00},	// Delay Fine Adjust 4  (Device Default)
		{0x003D,0x08},	// LVPECL OUT0  (Device Default)
		{0x003E,0x08},	// LVPECL OUT1  (Device Default)
		{0x003F,0x08},	// LVPECL OUT2  (Device Default)
		{0x0040,0x01},	// LVDS_CMOS OUT3  (Power Down OUT3)
		{0x0041,0x02},	// LVDS_CMOS OUT4  (Device Default)
		{0x0045,0x05},	// Clocks Select, Power-Down Options (Select Internal Sample Clock Source)
		{0x004A,0x00},	// Divider 0  (Device Default)
		{0x004B,0x80},	// Divider 0  (Bypass DIV0)
		{0x004C,0x11},	// Divider 1  (Device Default)
		{0x004D,0x80},	// Divider 1  (Bypass DIV1)
		{0x004E,0x33},	// Divider 2  (Device Default)
		{0x004F,0x80},	// Divider 2  (Bypass DIV2)
		{0x0050,0x00},	// Divider 3  (Device Default)
		{0x0051,0x00},	// Divider 3  (Device Default)
		{0x0052,0x11},	// Divider 4  (Device Default)
		{0x0053,0x80},	// Divider 4  (Bypass DIV4)
		{0x0058,0x00},	// Function Pin and Sync  (Device Default)
		{0x005A,0x01}	// Update Registers  (Update Registers)
		}
	},
	{  // ADS42LB69 - REFER TO THE ADS42LB69 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x04,0x00},	// LVDS Configuration #1  (Device Default)
		{0x05,0x00},	// LVDS Configuration #2  (Device Default)
		{0x06,0x00},	// Clock Divider  (Device Default)
		{0x07,0x00},	// SYNC Delay  (Device Default)
		{0x08,0x00},	// Power and Data Format Configuration  (Device Default)
		{0x0B,0x00},	// Channel A Gain Setting and Bit Ordering  (Device Default)
		{0x0C,0x00},	// Channel B Gain Setting and Bit Ordering  (Device Default)
		{0x0D,0x00},	// Over-range Setting  (Device Default)
		{0x0F,0x00},	// Test Pattern Selection  (Device Default)
		{0x10,0x00},	// Custom Pattern #1 (15:8) (Device Default)
		{0x11,0x00},	// Custom Pattern #1 (7:0)  (Device Default)
		{0x12,0x00},	// Custom Pattern #2 (15:8)  (Device Default)
		{0x13,0x00},	// Custom Pattern #2 (7:0)  (Device Default)
		{0x14,0x00},	// Output Drive Strength  (Device Default)
		{0x15,0x00},	// Output Driver Format  (Device Default)
		{0x16,0x00},	// Output Driver Timing  (Device Default)
		{0x17,0x00},	// Channel A Output Clock Timing  (Device Default)
		{0x18,0x00},	// Channel B Output Clock Timing  (Device Default)
		{0x1F,0xFF},	// Fast Over-range Threshold  (Device Default)
		{0x20,0x00},	// CTLR Pin Mode Select  (Device Default)
		{0x30,0x00}		// SYNC Enable  (Device Default)
		}
	},
	{  // ADS42LB69 - REFER TO THE ADS42LB69 DATASHEET FOR A DETAILED DESCRIPTION OF EACH REGISTER.
	   // Note: Each entry consists of Address, Data.
		{
		{0x04,0x00},	// LVDS Configuration #1  (Device Default)
		{0x05,0x00},	// LVDS Configuration #2  (Device Default)
		{0x06,0x00},	// Clock Divider  (Device Default)
		{0x07,0x00},	// SYNC Delay  (Device Default)
		{0x08,0x00},	// Power and Data Format Configuration  (Device Default)
		{0x0B,0x00},	// Channel A Gain Setting and Bit Ordering  (Device Default)
		{0x0C,0x00},	// Channel B Gain Setting and Bit Ordering  (Device Default)
		{0x0D,0x00},	// Over-range Setting  (Device Default)
		{0x0F,0x00},	// Test Pattern Selection  (Device Default)
		{0x10,0x00},	// Custom Pattern #1 (15:8) (Device Default)
		{0x11,0x00},	// Custom Pattern #1 (7:0)  (Device Default)
		{0x12,0x00},	// Custom Pattern #2 (15:8)  (Device Default)
		{0x13,0x00},	// Custom Pattern #2 (7:0)  (Device Default)
		{0x14,0x00},	// Output Drive Strength  (Device Default)
		{0x15,0x00},	// Output Driver Format  (Device Default)
		{0x16,0x00},	// Output Driver Timing  (Device Default)
		{0x17,0x00},	// Channel A Output Clock Timing  (Device Default)
		{0x18,0x00},	// Channel B Output Clock Timing  (Device Default)
		{0x1F,0xFF},	// Fast Over-range Threshold  (Device Default)
		{0x20,0x00},	// CTLR Pin Mode Select  (Device Default)
		{0x30,0x00}		// SYNC Enable  (Device Default)
		}
	}
};

#ifdef __cplusplus
}
#endif

#endif
